==> carpet-addons-not-found-1.18.2-2.0.0-sources.jar: carpetaddonsnotfound/mixins/StonecutterBlock_StonecuttersDoDamageMixin.java <==
package carpetaddonsnotfound.mixins;

import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Unique;

import static carpetaddonsnotfound.CarpetAddonsNotFoundSettings.stonecuttersDoDamage;

import net.minecraft.class_1282;
import net.minecraft.class_1297;
import net.minecraft.class_1309;
import net.minecraft.class_1937;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_2680;
import net.minecraft.class_3718;
import net.minecraft.class_4970;

@Mixin(class_3718.class)
public abstract class StonecutterBlock_StonecuttersDoDamageMixin extends class_2248 {
  StonecutterBlock_StonecuttersDoDamageMixin(class_4970.class_2251 settings) {
    super(settings);
  }

  @Override
  public void method_9591(class_1937 world, class_2338 pos, class_2680 state, class_1297 entity) {
    if (world.method_8608() || !world.method_8479(pos) || !stonecuttersCanDealDamage()) {
      return;
    }

    if (stonecuttersCanHeal() && entity instanceof class_1309 livingEntity) {
      livingEntity.method_6025(-stonecuttersDoDamage);
      return;
    }

    //#if MC>11802
    //$$ RegistryEntry<DamageType> type = getDamageTypeRegistryEntry(world);
    //#if MC>12101
    //$$ if (!(world instanceof ServerWorld serverWorld)) {
    //$$   return;
    //$$ }
    //#endif
    //$$
    //$$ entity.damage(
            //#if MC>12101
            //$$ serverWorld,
            //#endif
    //$$         new DamageSource(type, new Vec3d(pos.getX(), pos.getY(), pos.getZ())),
    //$$         stonecuttersDoDamage);
    //#else
    entity.method_5643(class_1282.field_5869, stonecuttersDoDamage);
    //#endif
  }

  @Unique
  private boolean stonecuttersCanDealDamage() {
    //#if MC>11802
    //$$ return stonecuttersDoDamage != 0.0f;
    //#else
    return stonecuttersDoDamage != 0;
    //#endif
  }

  @Unique
  private boolean stonecuttersCanHeal() {
    //#if MC>11802
    //$$ return stonecuttersDoDamage < 0.0f;
    //#else
    return stonecuttersDoDamage < 0;
    //#endif
  }

  //#if MC>11802
  //$$ @Unique
  //$$ private RegistryEntry<DamageType> getDamageTypeRegistryEntry(World world) {
  //$$   DynamicRegistryManager registryManager = world.getRegistryManager();
    //#if MC>12101
    //$$ Registry<DamageType> damageTypeRegistry = registryManager.getOrThrow(RegistryKeys.DAMAGE_TYPE);
    //$$ return damageTypeRegistry.getEntry(damageTypeRegistry.get(DamageTypes.GENERIC));
    //#else
    //$$ return registryManager.get(RegistryKeys.DAMAGE_TYPE).getEntry(DamageTypes.GENERIC).orElseThrow();
    //#endif
  //$$ }
  //#endif
}

==> carpet-addons-not-found-1.19.4-2.0.0-sources.jar: carpetaddonsnotfound/mixins/StonecutterBlock_StonecuttersDoDamageMixin.java <==
package carpetaddonsnotfound.mixins;

import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Unique;

import static carpetaddonsnotfound.CarpetAddonsNotFoundSettings.stonecuttersDoDamage;

import net.minecraft.class_1282;
import net.minecraft.class_1297;
import net.minecraft.class_1309;
import net.minecraft.class_1937;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_243;
import net.minecraft.class_2680;
import net.minecraft.class_3718;
import net.minecraft.class_4970;
import net.minecraft.class_5455;
import net.minecraft.class_6880;
import net.minecraft.class_7924;
import net.minecraft.class_8110;
import net.minecraft.class_8111;

@Mixin(class_3718.class)
public abstract class StonecutterBlock_StonecuttersDoDamageMixin extends class_2248 {
  StonecutterBlock_StonecuttersDoDamageMixin(class_4970.class_2251 settings) {
    super(settings);
  }

  @Override
  public void method_9591(class_1937 world, class_2338 pos, class_2680 state, class_1297 entity) {
    if (world.method_8608() || !world.method_8479(pos) || !stonecuttersCanDealDamage()) {
      return;
    }

    if (stonecuttersCanHeal() && entity instanceof class_1309 livingEntity) {
      livingEntity.method_6025(-stonecuttersDoDamage);
      return;
    }

    //#if MC>11802
    class_6880<class_8110> type = getDamageTypeRegistryEntry(world);
    //#if MC>12101
    //$$ if (!(world instanceof ServerWorld serverWorld)) {
    //$$   return;
    //$$ }
    //#endif

    entity.method_5643(
            //#if MC>12101
            //$$ serverWorld,
            //#endif
            new class_1282(type, new class_243(pos.method_10263(), pos.method_10264(), pos.method_10260())),
            stonecuttersDoDamage);
    //#else
    //$$ entity.damage(DamageSource.GENERIC, stonecuttersDoDamage);
    //#endif
  }

  @Unique
  private boolean stonecuttersCanDealDamage() {
    //#if MC>11802
    return stonecuttersDoDamage != 0.0f;
    //#else
    //$$ return stonecuttersDoDamage != 0;
    //#endif
  }

  @Unique
  private boolean stonecuttersCanHeal() {
    //#if MC>11802
    return stonecuttersDoDamage < 0.0f;
    //#else
    //$$ return stonecuttersDoDamage < 0;
    //#endif
  }

  //#if MC>11802
  @Unique
  private class_6880<class_8110> getDamageTypeRegistryEntry(class_1937 world) {
    class_5455 registryManager = world.method_30349();
    //#if MC>12101
    //$$ Registry<DamageType> damageTypeRegistry = registryManager.getOrThrow(RegistryKeys.DAMAGE_TYPE);
    //$$ return damageTypeRegistry.getEntry(damageTypeRegistry.get(DamageTypes.GENERIC));
    //#else
    return registryManager.method_30530(class_7924.field_42534).method_40264(class_8111.field_42348).orElseThrow();
    //#endif
  }
  //#endif
}
